#!/bin/sh
# test we are root
if [ "$(id -u)" != "0" ]; then
   echo "run as root now exitting"
   exit 1
fi

# build order is libfm-extra-dev menu-cache libfm then pcmanfm
export CFLAGS="-mtune=generic -Os -pipe"
export CXXFLAGS="-mtune=generic -Os -pipe -fno-exceptions -fno-rtti"

P1=libfm
P=$P1-extra-dev
V=1.3.2
SRC=$P1-$V
USER=`cat /etc/sysconfig/tcuser`
LIST="compiletc submitqc intltool glib2-dev "
for Z in $LIST
    do 
    su -c "tce-load -i $Z" $USER
done

cd /tmp
rm -rf *xz *tar
su -c "/usr/local/bin/wget -nc --no-check-certificate \
https://downloads.sourceforge.net/pcmanfm/$SRC.tar.xz   "  $USER
xz -d *xz && tar xvf *tar
cd $SRC
# Please consider passing --sysconfdir=/etc to configure.
# Otherwise default config files will be installed to wrong place
./configure  --prefix=/usr/local --sysconfdir=/etc --with-extra-only \
--with-gtk=no --disable-static
##################################
# prefix:           /usr/local
# sysconfdir:       /etc
# Enable compiler flags and other support for debugging:  no
# Build udisks support (Linux only, experimental):        no
# Build with libexif for faster thumbnail loading:        no
# Build demo program src/demo/libfm-demo:                 no
# Build with custom actions support (requires Vala):      no
# Large file support:                                     yes
# GIO module for preferred apps (for glib < 2.28 only):   not required
# Build libfm-gtk for Gtk+ version:                       none
# Build API doc with gtk-doc (recommended for make dist): no
####################################################   
make check # takes seconds
make install-strip DESTDIR=/tmp/$P
cd /tmp

# main
####### leave sym link delete install script
chmod 644 $P/usr/local/lib/*a

# licence not required for dev according to submitqc

# TCZ them
###########
LIST="$P  "
for Z in $LIST
do
	mksquashfs $Z $Z.tcz
	md5sum $Z.tcz > $Z.tcz.md5.txt
	cd $Z
	find usr -not -type d > /tmp/$Z.tcz.list
        sed 's|usr|/usr|g' -i /tmp/$Z.tcz.list
	cd /tmp
done

ls -hal

echo 'Title:          libfm-extra-dev.tcz
Description:    building dep for menu-cache  
Version:        1.3.2
Author:         https://github.com/lxde/libfm/blob/master/AUTHORS
Original-site:  https://downloads.sourceforge.net/pcmanfm
Copying-policy: GPL v2
Size:           16K          		
Extension_by:   aus9
Tags:           pcmanfm    
Comments:       Building dep for menu-cache 
 
Change-log:     2019/02/11 v 1.3.1 for 10x (aus9)
                2020/07/19 modify install script 
Current:        2023/03/20 v 1.3.2 on 14x ' > $P.tcz.info

readelf -d $P/usr/local/lib/libfm-extra.so | grep 'NEEDED'
###############################################
# 0x0000000000000001 (NEEDED)  Shared library: [libgio-2.0.so.0]    glib2
# 0x0000000000000001 (NEEDED)  Shared library: [libgthread-2.0.so.0] "
# 0x0000000000000001 (NEEDED)  Shared library: [libgobject-2.0.so.0]  "
# 0x0000000000000001 (NEEDED)  Shared library: [libglib-2.0.so.0]    "
# 0x0000000000000001 (NEEDED)  Shared library: [libm.so.6]TCB          
# 0x0000000000000001 (NEEDED)  Shared library: [libpthread.so.0]TCB     
# 0x0000000000000001 (NEEDED)  Shared library: [libc.so.6]TCB           
#######################################

echo 'glib2-dev.tcz      
intltool.tcz '> $P.tcz.dep

submitqc --libs
